{***************************************************************
 *
 * Unit Name : FileAttribDlg
 * Purpose   : File Date Time Attribute
 * Author    : Eugen Mihailescu
 * Company   : EM Quicksoft Romania SRL
 * Copyright : 1998,2002  All rights reserved.
 * Web Site  : http://www.em-quicksoft.com
 * Support   : support@em-quicksoft.com
 * History   : 03/17/2000
 *
 ****************************************************************}

Unit FileAttribDlg;

Interface

Uses
  Windows,
  Messages,
  SysUtils,
  Classes,
  Graphics,
  Controls,
  Forms,
  Dialogs,
  StdCtrls,
  ComCtrls,
  Menus;

Type
  TfrmFileAttrib = Class(TForm)
    OpenDialog: TOpenDialog;
    btnSelect: TButton;
    btnModify: TButton;
    grpSettings: TGroupBox;
    lblDate: TLabel;
    lblTime: TLabel;
    dtpDate: TDateTimePicker;
    dtpTime: TDateTimePicker;
    btnExit: TButton;
    lstFiles: TListView;
    PopupMenu1: TPopupMenu;
    SelectAll1: TMenuItem;
    DeselectAll1: TMenuItem;
    Procedure btnSelectClick(Sender: TObject);
    Procedure btnExitClick(Sender: TObject);
    Procedure SelectAll1Click(Sender: TObject);
    Procedure lstFilesColumnClick(Sender: TObject; Column: TListColumn);
    Procedure lstFilesCompare(Sender: TObject; Item1, Item2: TListItem;
      Data: Integer; Var Compare: Integer);
    Procedure btnModifyClick(Sender: TObject);
  private
    ColumnToSort: Integer;
    Procedure SetAttribute;
    Procedure SetFileDateTime(FileName: String; FDate: TDate; FTime: TTime);
  public
    { Public declarations }
  End;

Var
  frmFileAttrib     : TfrmFileAttrib;

Implementation

{$R *.DFM}
//******************* TfrmFileAttrib.btnSelectClick *************************

Procedure TfrmFileAttrib.btnSelectClick(Sender: TObject);
Var
  I                 : Integer;
Begin
  If OpenDialog.Execute Then
    For I := 0 To OpenDialog.files.Count - 1 Do
      With lstFiles.Items.Add Do
        Begin
          Caption := OpenDialog.files.Strings[I];
          SubItems.Add(DateTimeToStr(FileDateToDateTime(FileAge(Caption))));
        End;
End;
//******************* TfrmFileAttrib.btnExitClick *************************

Procedure TfrmFileAttrib.btnExitClick(Sender: TObject);
Begin
  Close;
End;
//******************* TfrmFileAttrib.SetAttribute *************************

Procedure TfrmFileAttrib.SetAttribute;
Var
  I                 : Integer;
Begin
  For I := 0 To lstFiles.Items.Count - 1 Do
    If lstFiles.Items.Item[I].Checked Then
      SetFileDateTime(lstFiles.Items.Item[I].Caption, dtpDate.Date,
        dtpTime.Time);
End;
//******************* TfrmFileAttrib.SelectAll1Click *************************

Procedure TfrmFileAttrib.SelectAll1Click(Sender: TObject);
Var
  I                 : Integer;
Begin
  For I := 0 To lstFiles.Items.Count - 1 Do
    lstFiles.Items.Item[I].Checked := Sender = SelectAll1;
End;
//******************* TfrmFileAttrib.lstFilesColumnClick *************************

Procedure TfrmFileAttrib.lstFilesColumnClick(Sender: TObject;
  Column: TListColumn);
Begin
  ColumnToSort := Column.Index;
  (Sender As TCustomListView).AlphaSort;
End;
//******************* TfrmFileAttrib.lstFilesCompare *************************

Procedure TfrmFileAttrib.lstFilesCompare(Sender: TObject; Item1,
  Item2: TListItem; Data: Integer; Var Compare: Integer);
Var
  ix                : Integer;
Begin
  If ColumnToSort = 0 Then
    Compare := CompareText(Item1.Caption, Item2.Caption)
  Else
    Begin
      ix := ColumnToSort - 1;
      Compare := CompareText(Item1.SubItems[ix], Item2.SubItems[ix]);
    End;
End;
//******************* TfrmFileAttrib.SetFileDateTime *************************

Procedure TfrmFileAttrib.SetFileDateTime(FileName: String; FDate: TDate; FTime:
  TTime);
Var
  H                 : Integer;
  DT                : TDateTime;
Begin
  ReplaceDate(DT, FDate);
  ReplaceTime(DT, FTime);
  H := FileOpen(FileName, fmOpenReadWrite Or fmShareDenyNone);
  Try
    If H <= 0 Then Exit;
    FileSetDate(H, DateTimeToFileDate(DT));
  Finally
    FileClose(H);
  End;
End;
//******************* TfrmFileAttrib.btnModifyClick *************************

Procedure TfrmFileAttrib.btnModifyClick(Sender: TObject);
Var
  I                 : Integer;
Begin
  SetAttribute;
  For I := 0 To lstFiles.Items.Count - 1 Do
    With lstFiles.Items.Item[I] Do
      SubItems.Text :=
        DateTimeToStr(FileDateToDateTime(FileAge(Caption)));
End;

End.

